pub struct FlushCommands<'w> { /* private fields */ }Expand description
A system parameter that can be used to explicitly flush pending command buffers to the render queue. This is typically not necessary, as command buffers are automatically flushed at the end of each render system. However, in some cases it may be useful to flush command buffers earlier.
Implementations
Sourceimpl<'w> FlushCommands<'w>
impl<'w> FlushCommands<'w>