pub struct RenderContextState(/* private fields */);Expand description
A resource that holds the current render context state, including command encoder and command buffers.
This is used internally by the RenderContext system parameter. Implements SystemBuffer to flush
command buffers at the end of each render system in topological system order.
Implementations
Sourceimpl RenderContextState
impl RenderContextState
pub fn finish(&mut self) -> Vec<CommandBuffer>